From dc6e2d91c53b0f0c16a6200bbb3371c09a847d08 Mon Sep 17 00:00:00 2001
From: Stainless Bot <107565488+stainless-bot@users.noreply.github.com>
Date: Tue, 21 Nov 2023 13:48:44 -0500
Subject: [PATCH] feat: add more api endpoints
---
.stats.yml | 2 +-
ai_test.go | 1 +
aibaai_test.go | 3 +
aihuggingface_test.go | 1 +
aimeta_test.go | 3 +
aimicrosoft_test.go | 1 +
aimistral_test.go | 1 +
aiopenai_test.go | 1 +
api.md | 28 +-
certificate.go | 257 ++++++++++++++++++
certificate_test.go | 91 +++++++
client.go | 10 +-
ip.go | 128 +++++++++
ip_test.go | 38 +++
zone.go | 106 ++++----
zone_test.go | 4 +
zonednssec_test.go | 2 +
zoneloadbalancer_test.go | 13 +-
zoneratelimit_test.go | 2 +
zonesetting_test.go | 1 +
zonesettingadvancedddo_test.go | 1 +
zonesettingalwaysonline_test.go | 2 +
zonesettingalwaysusehttp_test.go | 2 +
zonesettingautomatichttpsrewrite_test.go | 2 +
...ttingautomaticplatformoptimization_test.go | 2 +
zonesettingbrotli_test.go | 2 +
zonesettingbrowsercachettl_test.go | 2 +
zonesettingbrowsercheck_test.go | 2 +
zonesettingcachelevel_test.go | 2 +
zonesettingchallengettl_test.go | 2 +
zonesettingcipher_test.go | 2 +
zonesettingdevelopmentmode_test.go | 2 +
zonesettingearlyhint_test.go | 2 +
zonesettingemailobfuscation_test.go | 2 +
zonesettingh2prioritization_test.go | 2 +
zonesettinghotlinkprotection_test.go | 2 +
zonesettinghttp2_test.go | 2 +
zonesettinghttp3_test.go | 2 +
zonesettingimageresizing_test.go | 2 +
zonesettingipgeolocation_test.go | 2 +
zonesettingipv6_test.go | 2 +
zonesettingminify_test.go | 2 +
zonesettingmintlsversion_test.go | 2 +
zonesettingmirage_test.go | 2 +
zonesettingmobileredirect_test.go | 2 +
zonesettingnel_test.go | 2 +
zonesettingopportunisticencryption_test.go | 2 +
zonesettingopportunisticonion_test.go | 2 +
zonesettingorangetoorange_test.go | 2 +
zonesettingoriginerrorpagepassthrus_test.go | 2 +
zonesettingoriginmaxhttpversion_test.go | 2 +
zonesettingpolish_test.go | 2 +
zonesettingprefetchpreload_test.go | 2 +
zonesettingprivacypass_test.go | 2 +
zonesettingproxyreadtimeout_test.go | 2 +
zonesettingpseudoipv4_test.go | 2 +
zonesettingresponsebuffering_test.go | 2 +
zonesettingrocketloader_test.go | 2 +
zonesettingsecurityheader_test.go | 2 +
zonesettingsecuritylevel_test.go | 2 +
zonesettingserversideexclude_test.go | 2 +
zonesettingsortquerystringforcach_test.go | 2 +
zonesettingssl_test.go | 2 +
zonesettingsslrecommender_test.go | 2 +
zonesettingtls13_test.go | 2 +
zonesettingtlsclientauth_test.go | 2 +
zonesettingtrueclientipheader_test.go | 2 +
zonesettingwaf_test.go | 2 +
zonesettingwebp_test.go | 2 +
zonesettingwebsocket_test.go | 2 +
70 files changed, 725 insertions(+), 67 deletions(-)
create mode 100644 certificate.go
create mode 100644 certificate_test.go
create mode 100644 ip.go
create mode 100644 ip_test.go
diff --git a/.stats.yml b/.stats.yml
index b0a6dec0e28..adbb7cab3be 100644
--- a/.stats.yml
+++ b/.stats.yml
@@ -1 +1 @@
-configured_endpoints: 126
+configured_endpoints: 130
diff --git a/ai_test.go b/ai_test.go
index 38f6681d26e..85ee23eb143 100644
--- a/ai_test.go
+++ b/ai_test.go
@@ -14,6 +14,7 @@ import (
)
func TestAIRun(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/aibaai_test.go b/aibaai_test.go
index 9915bee4182..6f3452da077 100644
--- a/aibaai_test.go
+++ b/aibaai_test.go
@@ -15,6 +15,7 @@ import (
)
func TestAIBaaiBgeBaseEnV1_5(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -44,6 +45,7 @@ func TestAIBaaiBgeBaseEnV1_5(t *testing.T) {
}
func TestAIBaaiBgeLargeEnV1_5(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -73,6 +75,7 @@ func TestAIBaaiBgeLargeEnV1_5(t *testing.T) {
}
func TestAIBaaiBgeSmallEnV1_5(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/aihuggingface_test.go b/aihuggingface_test.go
index 3cf1c88e704..f5af4255ac8 100644
--- a/aihuggingface_test.go
+++ b/aihuggingface_test.go
@@ -14,6 +14,7 @@ import (
)
func TestAIHuggingfaceDistilbertSst2Int8(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/aimeta_test.go b/aimeta_test.go
index 147f616febd..14273da4731 100644
--- a/aimeta_test.go
+++ b/aimeta_test.go
@@ -14,6 +14,7 @@ import (
)
func TestAIMetaLlama2_7bChatFp16WithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -44,6 +45,7 @@ func TestAIMetaLlama2_7bChatFp16WithOptionalParams(t *testing.T) {
}
func TestAIMetaLlama2_7bChatInt8WithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -74,6 +76,7 @@ func TestAIMetaLlama2_7bChatInt8WithOptionalParams(t *testing.T) {
}
func TestAIMetaM2m100_1_2bWithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/aimicrosoft_test.go b/aimicrosoft_test.go
index aa8434aaa6b..8784ee6d22e 100644
--- a/aimicrosoft_test.go
+++ b/aimicrosoft_test.go
@@ -14,6 +14,7 @@ import (
)
func TestAIMicrosoftResnet50(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/aimistral_test.go b/aimistral_test.go
index 2ef43a5137d..a9e8330776f 100644
--- a/aimistral_test.go
+++ b/aimistral_test.go
@@ -14,6 +14,7 @@ import (
)
func TestAIMistralMistral7bInstructV0_1WithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/aiopenai_test.go b/aiopenai_test.go
index a63763211c2..82fcf73ebe7 100644
--- a/aiopenai_test.go
+++ b/aiopenai_test.go
@@ -14,6 +14,7 @@ import (
)
func TestAIOpenAIWhisper(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/api.md b/api.md
index 611e1cdaecf..0105c8c3313 100644
--- a/api.md
+++ b/api.md
@@ -1,3 +1,27 @@
+# Certificates
+
+Response Types:
+
+- cloudflare.CertificateResponseSingleID9CkVsmTj
+- cloudflare.SchemasCertificateResponseSingle
+
+Methods:
+
+- client.Certificates.New(ctx context.Context, body cloudflare.CertificateNewParams) (cloudflare.SchemasCertificateResponseSingle, error)
+- client.Certificates.Get(ctx context.Context, identifier string) (cloudflare.SchemasCertificateResponseSingle, error)
+- client.Certificates.Delete(ctx context.Context, identifier string) (cloudflare.CertificateResponseSingleID9CkVsmTj, error)
+
+# IPs
+
+Response Types:
+
+- cloudflare.IP
+- cloudflare.IPListResponse
+
+Methods:
+
+- client.IPs.List(ctx context.Context) (cloudflare.IPListResponse, error)
+
# Zones
Params Types:
@@ -6,8 +30,8 @@ Params Types:
Response Types:
+- cloudflare.APIResponseSingleID
- cloudflare.SessionAffinity
-- cloudflare.ZoneAPIResponseSingleID
- cloudflare.ZoneNewResponse
- cloudflare.ZoneGetResponse
- cloudflare.ZoneUpdateResponse
@@ -19,7 +43,7 @@ Methods:
- client.Zones.Get(ctx context.Context, identifier string) (cloudflare.ZoneGetResponse, error)
- client.Zones.Update(ctx context.Context, identifier string, body cloudflare.ZoneUpdateParams) (cloudflare.ZoneUpdateResponse, error)
- client.Zones.List(ctx context.Context, query cloudflare.ZoneListParams) (cloudflare.ZoneListResponse, error)
-- client.Zones.Delete(ctx context.Context, identifier string) (cloudflare.ZoneAPIResponseSingleID, error)
+- client.Zones.Delete(ctx context.Context, identifier string) (cloudflare.APIResponseSingleID, error)
## LoadBalancers
diff --git a/certificate.go b/certificate.go
new file mode 100644
index 00000000000..d9a63dd4b56
--- /dev/null
+++ b/certificate.go
@@ -0,0 +1,257 @@
+// File generated from our OpenAPI spec by Stainless.
+
+package cloudflare
+
+import (
+ "context"
+ "fmt"
+ "net/http"
+
+ "github.com/cloudflare/cloudflare-sdk-go/internal/apijson"
+ "github.com/cloudflare/cloudflare-sdk-go/internal/param"
+ "github.com/cloudflare/cloudflare-sdk-go/internal/requestconfig"
+ "github.com/cloudflare/cloudflare-sdk-go/option"
+)
+
+// CertificateService contains methods and other services that help with
+// interacting with the cloudflare API. Note, unlike clients, this service does not
+// read variables from the environment automatically. You should not instantiate
+// this service directly, and instead use the [NewCertificateService] method
+// instead.
+type CertificateService struct {
+ Options []option.RequestOption
+}
+
+// NewCertificateService generates a new service that applies the given options to
+// each request. These options are applied after the parent client's options (if
+// there is one), and before any request-specific options.
+func NewCertificateService(opts ...option.RequestOption) (r *CertificateService) {
+ r = &CertificateService{}
+ r.Options = opts
+ return
+}
+
+// Create an Origin CA certificate. Use your Origin CA Key as your User Service Key
+// when calling this endpoint ([see above](#requests)).
+func (r *CertificateService) New(ctx context.Context, body CertificateNewParams, opts ...option.RequestOption) (res *SchemasCertificateResponseSingle, err error) {
+ opts = append(r.Options[:], opts...)
+ path := "certificates"
+ err = requestconfig.ExecuteNewRequest(ctx, http.MethodPost, path, body, &res, opts...)
+ return
+}
+
+// Get an existing Origin CA certificate by its serial number. Use your Origin CA
+// Key as your User Service Key when calling this endpoint
+// ([see above](#requests)).
+func (r *CertificateService) Get(ctx context.Context, identifier string, opts ...option.RequestOption) (res *SchemasCertificateResponseSingle, err error) {
+ opts = append(r.Options[:], opts...)
+ path := fmt.Sprintf("certificates/%s", identifier)
+ err = requestconfig.ExecuteNewRequest(ctx, http.MethodGet, path, nil, &res, opts...)
+ return
+}
+
+// Revoke an existing Origin CA certificate by its serial number. Use your Origin
+// CA Key as your User Service Key when calling this endpoint
+// ([see above](#requests)).
+func (r *CertificateService) Delete(ctx context.Context, identifier string, opts ...option.RequestOption) (res *CertificateResponseSingleID9CkVsmTj, err error) {
+ opts = append(r.Options[:], opts...)
+ path := fmt.Sprintf("certificates/%s", identifier)
+ err = requestconfig.ExecuteNewRequest(ctx, http.MethodDelete, path, nil, &res, opts...)
+ return
+}
+
+type CertificateResponseSingleID9CkVsmTj struct {
+ Errors []CertificateResponseSingleID9CkVsmTjError `json:"errors"`
+ Messages []CertificateResponseSingleID9CkVsmTjMessage `json:"messages"`
+ Result CertificateResponseSingleID9CkVsmTjResult `json:"result"`
+ // Whether the API call was successful
+ Success CertificateResponseSingleID9CkVsmTjSuccess `json:"success"`
+ JSON certificateResponseSingleId9CkVsmTjJSON `json:"-"`
+}
+
+// certificateResponseSingleId9CkVsmTjJSON contains the JSON metadata for the
+// struct [CertificateResponseSingleID9CkVsmTj]
+type certificateResponseSingleId9CkVsmTjJSON struct {
+ Errors apijson.Field
+ Messages apijson.Field
+ Result apijson.Field
+ Success apijson.Field
+ raw string
+ ExtraFields map[string]apijson.Field
+}
+
+func (r *CertificateResponseSingleID9CkVsmTj) UnmarshalJSON(data []byte) (err error) {
+ return apijson.UnmarshalRoot(data, r)
+}
+
+type CertificateResponseSingleID9CkVsmTjError struct {
+ Code int64 `json:"code,required"`
+ Message string `json:"message,required"`
+ JSON certificateResponseSingleId9CkVsmTjErrorJSON `json:"-"`
+}
+
+// certificateResponseSingleId9CkVsmTjErrorJSON contains the JSON metadata for the
+// struct [CertificateResponseSingleID9CkVsmTjError]
+type certificateResponseSingleId9CkVsmTjErrorJSON struct {
+ Code apijson.Field
+ Message apijson.Field
+ raw string
+ ExtraFields map[string]apijson.Field
+}
+
+func (r *CertificateResponseSingleID9CkVsmTjError) UnmarshalJSON(data []byte) (err error) {
+ return apijson.UnmarshalRoot(data, r)
+}
+
+type CertificateResponseSingleID9CkVsmTjMessage struct {
+ Code int64 `json:"code,required"`
+ Message string `json:"message,required"`
+ JSON certificateResponseSingleId9CkVsmTjMessageJSON `json:"-"`
+}
+
+// certificateResponseSingleId9CkVsmTjMessageJSON contains the JSON metadata for
+// the struct [CertificateResponseSingleID9CkVsmTjMessage]
+type certificateResponseSingleId9CkVsmTjMessageJSON struct {
+ Code apijson.Field
+ Message apijson.Field
+ raw string
+ ExtraFields map[string]apijson.Field
+}
+
+func (r *CertificateResponseSingleID9CkVsmTjMessage) UnmarshalJSON(data []byte) (err error) {
+ return apijson.UnmarshalRoot(data, r)
+}
+
+type CertificateResponseSingleID9CkVsmTjResult struct {
+ // Identifier
+ ID string `json:"id"`
+ JSON certificateResponseSingleId9CkVsmTjResultJSON `json:"-"`
+}
+
+// certificateResponseSingleId9CkVsmTjResultJSON contains the JSON metadata for the
+// struct [CertificateResponseSingleID9CkVsmTjResult]
+type certificateResponseSingleId9CkVsmTjResultJSON struct {
+ ID apijson.Field
+ raw string
+ ExtraFields map[string]apijson.Field
+}
+
+func (r *CertificateResponseSingleID9CkVsmTjResult) UnmarshalJSON(data []byte) (err error) {
+ return apijson.UnmarshalRoot(data, r)
+}
+
+// Whether the API call was successful
+type CertificateResponseSingleID9CkVsmTjSuccess bool
+
+const (
+ CertificateResponseSingleID9CkVsmTjSuccessTrue CertificateResponseSingleID9CkVsmTjSuccess = true
+)
+
+type SchemasCertificateResponseSingle struct {
+ Errors []SchemasCertificateResponseSingleError `json:"errors"`
+ Messages []SchemasCertificateResponseSingleMessage `json:"messages"`
+ Result interface{} `json:"result"`
+ // Whether the API call was successful
+ Success SchemasCertificateResponseSingleSuccess `json:"success"`
+ JSON schemasCertificateResponseSingleJSON `json:"-"`
+}
+
+// schemasCertificateResponseSingleJSON contains the JSON metadata for the struct
+// [SchemasCertificateResponseSingle]
+type schemasCertificateResponseSingleJSON struct {
+ Errors apijson.Field
+ Messages apijson.Field
+ Result apijson.Field
+ Success apijson.Field
+ raw string
+ ExtraFields map[string]apijson.Field
+}
+
+func (r *SchemasCertificateResponseSingle) UnmarshalJSON(data []byte) (err error) {
+ return apijson.UnmarshalRoot(data, r)
+}
+
+type SchemasCertificateResponseSingleError struct {
+ Code int64 `json:"code,required"`
+ Message string `json:"message,required"`
+ JSON schemasCertificateResponseSingleErrorJSON `json:"-"`
+}
+
+// schemasCertificateResponseSingleErrorJSON contains the JSON metadata for the
+// struct [SchemasCertificateResponseSingleError]
+type schemasCertificateResponseSingleErrorJSON struct {
+ Code apijson.Field
+ Message apijson.Field
+ raw string
+ ExtraFields map[string]apijson.Field
+}
+
+func (r *SchemasCertificateResponseSingleError) UnmarshalJSON(data []byte) (err error) {
+ return apijson.UnmarshalRoot(data, r)
+}
+
+type SchemasCertificateResponseSingleMessage struct {
+ Code int64 `json:"code,required"`
+ Message string `json:"message,required"`
+ JSON schemasCertificateResponseSingleMessageJSON `json:"-"`
+}
+
+// schemasCertificateResponseSingleMessageJSON contains the JSON metadata for the
+// struct [SchemasCertificateResponseSingleMessage]
+type schemasCertificateResponseSingleMessageJSON struct {
+ Code apijson.Field
+ Message apijson.Field
+ raw string
+ ExtraFields map[string]apijson.Field
+}
+
+func (r *SchemasCertificateResponseSingleMessage) UnmarshalJSON(data []byte) (err error) {
+ return apijson.UnmarshalRoot(data, r)
+}
+
+// Whether the API call was successful
+type SchemasCertificateResponseSingleSuccess bool
+
+const (
+ SchemasCertificateResponseSingleSuccessTrue SchemasCertificateResponseSingleSuccess = true
+)
+
+type CertificateNewParams struct {
+ // The Certificate Signing Request (CSR). Must be newline-encoded.
+ Csr param.Field[string] `json:"csr"`
+ // Array of hostnames or wildcard names (e.g., \*.example.com) bound to the
+ // certificate.
+ Hostnames param.Field[[]interface{}] `json:"hostnames"`
+ // Signature type desired on certificate ("origin-rsa" (rsa), "origin-ecc" (ecdsa),
+ // or "keyless-certificate" (for Keyless SSL servers).
+ RequestType param.Field[CertificateNewParamsRequestType] `json:"request_type"`
+ // The number of days for which the certificate should be valid.
+ RequestedValidity param.Field[CertificateNewParamsRequestedValidity] `json:"requested_validity"`
+}
+
+func (r CertificateNewParams) MarshalJSON() (data []byte, err error) {
+ return apijson.MarshalRoot(r)
+}
+
+// Signature type desired on certificate ("origin-rsa" (rsa), "origin-ecc" (ecdsa),
+// or "keyless-certificate" (for Keyless SSL servers).
+type CertificateNewParamsRequestType string
+
+const (
+ CertificateNewParamsRequestTypeOriginRsa CertificateNewParamsRequestType = "origin-rsa"
+ CertificateNewParamsRequestTypeOriginEcc CertificateNewParamsRequestType = "origin-ecc"
+ CertificateNewParamsRequestTypeKeylessCertificate CertificateNewParamsRequestType = "keyless-certificate"
+)
+
+// The number of days for which the certificate should be valid.
+type CertificateNewParamsRequestedValidity float64
+
+const (
+ CertificateNewParamsRequestedValidity7 CertificateNewParamsRequestedValidity = 7
+ CertificateNewParamsRequestedValidity30 CertificateNewParamsRequestedValidity = 30
+ CertificateNewParamsRequestedValidity90 CertificateNewParamsRequestedValidity = 90
+ CertificateNewParamsRequestedValidity365 CertificateNewParamsRequestedValidity = 365
+ CertificateNewParamsRequestedValidity730 CertificateNewParamsRequestedValidity = 730
+ CertificateNewParamsRequestedValidity1095 CertificateNewParamsRequestedValidity = 1095
+ CertificateNewParamsRequestedValidity5475 CertificateNewParamsRequestedValidity = 5475
+)
diff --git a/certificate_test.go b/certificate_test.go
new file mode 100644
index 00000000000..96346d215e9
--- /dev/null
+++ b/certificate_test.go
@@ -0,0 +1,91 @@
+// File generated from our OpenAPI spec by Stainless.
+
+package cloudflare_test
+
+import (
+ "context"
+ "errors"
+ "os"
+ "testing"
+
+ "github.com/cloudflare/cloudflare-sdk-go"
+ "github.com/cloudflare/cloudflare-sdk-go/internal/testutil"
+ "github.com/cloudflare/cloudflare-sdk-go/option"
+)
+
+func TestCertificateNewWithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
+ baseURL := "http://localhost:4010"
+ if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
+ baseURL = envURL
+ }
+ if !testutil.CheckTestServer(t, baseURL) {
+ return
+ }
+ client := cloudflare.NewClient(
+ option.WithBaseURL(baseURL),
+ option.WithAPIKey("my-cloudflare-api-key"),
+ option.WithEmail("dev@cloudflare.com"),
+ )
+ _, err := client.Certificates.New(context.TODO(), cloudflare.CertificateNewParams{
+ Csr: cloudflare.F("-----BEGIN CERTIFICATE REQUEST-----\nMIICxzCCAa8CAQAwSDELMAkGA1UEBhMCVVMxFjAUBgNVBAgTDVNhbiBGcmFuY2lz\nY28xCzAJBgNVBAcTAkNBMRQwEgYDVQQDEwtleGFtcGxlLm5ldDCCASIwDQYJKoZI\nhvcNAQEBBQADggEPADCCAQoCggEBALxejtu4b+jPdFeFi6OUsye8TYJQBm3WfCvL\nHu5EvijMO/4Z2TImwASbwUF7Ir8OLgH+mGlQZeqyNvGoSOMEaZVXcYfpR1hlVak8\n4GGVr+04IGfOCqaBokaBFIwzclGZbzKmLGwIQioNxGfqFm6RGYGA3be2Je2iseBc\nN8GV1wYmvYE0RR+yWweJCTJ157exyRzu7sVxaEW9F87zBQLyOnwXc64rflXslRqi\ng7F7w5IaQYOl8yvmk/jEPCAha7fkiUfEpj4N12+oPRiMvleJF98chxjD4MH39c5I\nuOslULhrWunfh7GB1jwWNA9y44H0snrf+xvoy2TcHmxvma9Eln8CAwEAAaA6MDgG\nCSqGSIb3DQEJDjErMCkwJwYDVR0RBCAwHoILZXhhbXBsZS5uZXSCD3d3dy5leGFt\ncGxlLm5ldDANBgkqhkiG9w0BAQsFAAOCAQEAcBaX6dOnI8ncARrI9ZSF2AJX+8mx\npTHY2+Y2C0VvrVDGMtbBRH8R9yMbqWtlxeeNGf//LeMkSKSFa4kbpdx226lfui8/\nauRDBTJGx2R1ccUxmLZXx4my0W5iIMxunu+kez+BDlu7bTT2io0uXMRHue4i6quH\nyc5ibxvbJMjR7dqbcanVE10/34oprzXQsJ/VmSuZNXtjbtSKDlmcpw6To/eeAJ+J\nhXykcUihvHyG4A1m2R6qpANBjnA0pHexfwM/SgfzvpbvUg0T1ubmer8BgTwCKIWs\ndcWYTthM51JIqRBfNqy4QcBnX+GY05yltEEswQI55wdiS3CjTTA67sdbcQ==\n-----END CERTIFICATE REQUEST-----"),
+ Hostnames: cloudflare.F([]interface{}{"example.com", "*.example.com"}),
+ RequestType: cloudflare.F(cloudflare.CertificateNewParamsRequestTypeOriginRsa),
+ RequestedValidity: cloudflare.F(cloudflare.CertificateNewParamsRequestedValidity5475),
+ })
+ if err != nil {
+ var apierr *cloudflare.Error
+ if errors.As(err, &apierr) {
+ t.Log(string(apierr.DumpRequest(true)))
+ }
+ t.Fatalf("err should be nil: %s", err.Error())
+ }
+}
+
+func TestCertificateGet(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
+ baseURL := "http://localhost:4010"
+ if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
+ baseURL = envURL
+ }
+ if !testutil.CheckTestServer(t, baseURL) {
+ return
+ }
+ client := cloudflare.NewClient(
+ option.WithBaseURL(baseURL),
+ option.WithAPIKey("my-cloudflare-api-key"),
+ option.WithEmail("dev@cloudflare.com"),
+ )
+ _, err := client.Certificates.Get(context.TODO(), "023e105f4ecef8ad9ca31a8372d0c353")
+ if err != nil {
+ var apierr *cloudflare.Error
+ if errors.As(err, &apierr) {
+ t.Log(string(apierr.DumpRequest(true)))
+ }
+ t.Fatalf("err should be nil: %s", err.Error())
+ }
+}
+
+func TestCertificateDelete(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
+ baseURL := "http://localhost:4010"
+ if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
+ baseURL = envURL
+ }
+ if !testutil.CheckTestServer(t, baseURL) {
+ return
+ }
+ client := cloudflare.NewClient(
+ option.WithBaseURL(baseURL),
+ option.WithAPIKey("my-cloudflare-api-key"),
+ option.WithEmail("dev@cloudflare.com"),
+ )
+ _, err := client.Certificates.Delete(context.TODO(), "023e105f4ecef8ad9ca31a8372d0c353")
+ if err != nil {
+ var apierr *cloudflare.Error
+ if errors.As(err, &apierr) {
+ t.Log(string(apierr.DumpRequest(true)))
+ }
+ t.Fatalf("err should be nil: %s", err.Error())
+ }
+}
diff --git a/client.go b/client.go
index ba19853dbf3..138702cf43d 100644
--- a/client.go
+++ b/client.go
@@ -12,9 +12,11 @@ import (
// interacting with the cloudflare API. You should not instantiate this client
// directly, and instead use the [NewClient] method instead.
type Client struct {
- Options []option.RequestOption
- Zones *ZoneService
- AI *AIService
+ Options []option.RequestOption
+ Certificates *CertificateService
+ IPs *IPService
+ Zones *ZoneService
+ AI *AIService
}
// NewClient generates a new client with the default option read from the
@@ -33,6 +35,8 @@ func NewClient(opts ...option.RequestOption) (r *Client) {
r = &Client{Options: opts}
+ r.Certificates = NewCertificateService(opts...)
+ r.IPs = NewIPService(opts...)
r.Zones = NewZoneService(opts...)
r.AI = NewAIService(opts...)
diff --git a/ip.go b/ip.go
new file mode 100644
index 00000000000..7d49b16baf7
--- /dev/null
+++ b/ip.go
@@ -0,0 +1,128 @@
+// File generated from our OpenAPI spec by Stainless.
+
+package cloudflare
+
+import (
+ "context"
+ "net/http"
+
+ "github.com/cloudflare/cloudflare-sdk-go/internal/apijson"
+ "github.com/cloudflare/cloudflare-sdk-go/internal/requestconfig"
+ "github.com/cloudflare/cloudflare-sdk-go/option"
+)
+
+// IPService contains methods and other services that help with interacting with
+// the cloudflare API. Note, unlike clients, this service does not read variables
+// from the environment automatically. You should not instantiate this service
+// directly, and instead use the [NewIPService] method instead.
+type IPService struct {
+ Options []option.RequestOption
+}
+
+// NewIPService generates a new service that applies the given options to each
+// request. These options are applied after the parent client's options (if there
+// is one), and before any request-specific options.
+func NewIPService(opts ...option.RequestOption) (r *IPService) {
+ r = &IPService{}
+ r.Options = opts
+ return
+}
+
+// Get Cloudflare IPs.
+func (r *IPService) List(ctx context.Context, opts ...option.RequestOption) (res *IPListResponse, err error) {
+ opts = append(r.Options[:], opts...)
+ path := "ips"
+ err = requestconfig.ExecuteNewRequest(ctx, http.MethodGet, path, nil, &res, opts...)
+ return
+}
+
+type IP struct {
+ // A digest of the IP data. Useful for determining if the data has changed.
+ Etag string `json:"etag"`
+ // List of Cloudflare IPv4 CIDR addresses.
+ Ipv4Cidrs []string `json:"ipv4_cidrs"`
+ // List of Cloudflare IPv6 CIDR addresses.
+ Ipv6Cidrs []string `json:"ipv6_cidrs"`
+ JSON ipJSON `json:"-"`
+}
+
+// ipJSON contains the JSON metadata for the struct [IP]
+type ipJSON struct {
+ Etag apijson.Field
+ Ipv4Cidrs apijson.Field
+ Ipv6Cidrs apijson.Field
+ raw string
+ ExtraFields map[string]apijson.Field
+}
+
+func (r *IP) UnmarshalJSON(data []byte) (err error) {
+ return apijson.UnmarshalRoot(data, r)
+}
+
+type IPListResponse struct {
+ Errors []IPListResponseError `json:"errors"`
+ Messages []IPListResponseMessage `json:"messages"`
+ Result IP `json:"result"`
+ // Whether the API call was successful
+ Success IPListResponseSuccess `json:"success"`
+ JSON ipListResponseJSON `json:"-"`
+}
+
+// ipListResponseJSON contains the JSON metadata for the struct [IPListResponse]
+type ipListResponseJSON struct {
+ Errors apijson.Field
+ Messages apijson.Field
+ Result apijson.Field
+ Success apijson.Field
+ raw string
+ ExtraFields map[string]apijson.Field
+}
+
+func (r *IPListResponse) UnmarshalJSON(data []byte) (err error) {
+ return apijson.UnmarshalRoot(data, r)
+}
+
+type IPListResponseError struct {
+ Code int64 `json:"code,required"`
+ Message string `json:"message,required"`
+ JSON ipListResponseErrorJSON `json:"-"`
+}
+
+// ipListResponseErrorJSON contains the JSON metadata for the struct
+// [IPListResponseError]
+type ipListResponseErrorJSON struct {
+ Code apijson.Field
+ Message apijson.Field
+ raw string
+ ExtraFields map[string]apijson.Field
+}
+
+func (r *IPListResponseError) UnmarshalJSON(data []byte) (err error) {
+ return apijson.UnmarshalRoot(data, r)
+}
+
+type IPListResponseMessage struct {
+ Code int64 `json:"code,required"`
+ Message string `json:"message,required"`
+ JSON ipListResponseMessageJSON `json:"-"`
+}
+
+// ipListResponseMessageJSON contains the JSON metadata for the struct
+// [IPListResponseMessage]
+type ipListResponseMessageJSON struct {
+ Code apijson.Field
+ Message apijson.Field
+ raw string
+ ExtraFields map[string]apijson.Field
+}
+
+func (r *IPListResponseMessage) UnmarshalJSON(data []byte) (err error) {
+ return apijson.UnmarshalRoot(data, r)
+}
+
+// Whether the API call was successful
+type IPListResponseSuccess bool
+
+const (
+ IPListResponseSuccessTrue IPListResponseSuccess = true
+)
diff --git a/ip_test.go b/ip_test.go
new file mode 100644
index 00000000000..7e1962d91af
--- /dev/null
+++ b/ip_test.go
@@ -0,0 +1,38 @@
+// File generated from our OpenAPI spec by Stainless.
+
+package cloudflare_test
+
+import (
+ "context"
+ "errors"
+ "os"
+ "testing"
+
+ "github.com/cloudflare/cloudflare-sdk-go"
+ "github.com/cloudflare/cloudflare-sdk-go/internal/testutil"
+ "github.com/cloudflare/cloudflare-sdk-go/option"
+)
+
+func TestIPList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
+ baseURL := "http://localhost:4010"
+ if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
+ baseURL = envURL
+ }
+ if !testutil.CheckTestServer(t, baseURL) {
+ return
+ }
+ client := cloudflare.NewClient(
+ option.WithBaseURL(baseURL),
+ option.WithAPIKey("my-cloudflare-api-key"),
+ option.WithEmail("dev@cloudflare.com"),
+ )
+ _, err := client.IPs.List(context.TODO())
+ if err != nil {
+ var apierr *cloudflare.Error
+ if errors.As(err, &apierr) {
+ t.Log(string(apierr.DumpRequest(true)))
+ }
+ t.Fatalf("err should be nil: %s", err.Error())
+ }
+}
diff --git a/zone_test.go b/zone_test.go
index c01e7ce3475..0ec273d433e 100644
--- a/zone_test.go
+++ b/zone_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneNewWithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneNewWithOptionalParams(t *testing.T) {
}
func TestZoneGet(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -66,6 +68,7 @@ func TestZoneGet(t *testing.T) {
}
func TestZoneUpdateWithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -99,6 +102,7 @@ func TestZoneUpdateWithOptionalParams(t *testing.T) {
}
func TestZoneListWithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonednssec_test.go b/zonednssec_test.go
index c9ccebbc7d6..e3d2221b180 100644
--- a/zonednssec_test.go
+++ b/zonednssec_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneDnssecGet(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -37,6 +38,7 @@ func TestZoneDnssecGet(t *testing.T) {
}
func TestZoneDnssecUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zoneloadbalancer_test.go b/zoneloadbalancer_test.go
index bb7acaa4707..0c6c31c3fab 100644
--- a/zoneloadbalancer_test.go
+++ b/zoneloadbalancer_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneLoadBalancerNewWithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -138,7 +139,6 @@ func TestZoneLoadBalancerNewWithOptionalParams(t *testing.T) {
"1": "9290f38c5d07c2e2f4df57b1f61d4196",
},
}),
- SessionAffinity: cloudflare.F(cloudflare.SessionAffinityCookie),
SessionAffinityAttributes: cloudflare.F(cloudflare.ZoneLoadBalancerNewParamsRulesOverridesSessionAffinityAttributes{
DrainDuration: cloudflare.F(100.000000),
Samesite: cloudflare.F(cloudflare.ZoneLoadBalancerNewParamsRulesOverridesSessionAffinityAttributesSamesiteAuto),
@@ -209,7 +209,6 @@ func TestZoneLoadBalancerNewWithOptionalParams(t *testing.T) {
"1": "9290f38c5d07c2e2f4df57b1f61d4196",
},
}),
- SessionAffinity: cloudflare.F(cloudflare.SessionAffinityCookie),
SessionAffinityAttributes: cloudflare.F(cloudflare.ZoneLoadBalancerNewParamsRulesOverridesSessionAffinityAttributes{
DrainDuration: cloudflare.F(100.000000),
Samesite: cloudflare.F(cloudflare.ZoneLoadBalancerNewParamsRulesOverridesSessionAffinityAttributesSamesiteAuto),
@@ -280,7 +279,6 @@ func TestZoneLoadBalancerNewWithOptionalParams(t *testing.T) {
"1": "9290f38c5d07c2e2f4df57b1f61d4196",
},
}),
- SessionAffinity: cloudflare.F(cloudflare.SessionAffinityCookie),
SessionAffinityAttributes: cloudflare.F(cloudflare.ZoneLoadBalancerNewParamsRulesOverridesSessionAffinityAttributes{
DrainDuration: cloudflare.F(100.000000),
Samesite: cloudflare.F(cloudflare.ZoneLoadBalancerNewParamsRulesOverridesSessionAffinityAttributesSamesiteAuto),
@@ -294,7 +292,6 @@ func TestZoneLoadBalancerNewWithOptionalParams(t *testing.T) {
Priority: cloudflare.F(int64(0)),
Terminates: cloudflare.F(true),
}}),
- SessionAffinity: cloudflare.F(cloudflare.SessionAffinityCookie),
SessionAffinityAttributes: cloudflare.F(cloudflare.ZoneLoadBalancerNewParamsSessionAffinityAttributes{
DrainDuration: cloudflare.F(100.000000),
Samesite: cloudflare.F(cloudflare.ZoneLoadBalancerNewParamsSessionAffinityAttributesSamesiteAuto),
@@ -316,6 +313,7 @@ func TestZoneLoadBalancerNewWithOptionalParams(t *testing.T) {
}
func TestZoneLoadBalancerGet(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -343,6 +341,7 @@ func TestZoneLoadBalancerGet(t *testing.T) {
}
func TestZoneLoadBalancerUpdateWithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -469,7 +468,6 @@ func TestZoneLoadBalancerUpdateWithOptionalParams(t *testing.T) {
"1": "9290f38c5d07c2e2f4df57b1f61d4196",
},
}),
- SessionAffinity: cloudflare.F(cloudflare.SessionAffinityCookie),
SessionAffinityAttributes: cloudflare.F(cloudflare.ZoneLoadBalancerUpdateParamsRulesOverridesSessionAffinityAttributes{
DrainDuration: cloudflare.F(100.000000),
Samesite: cloudflare.F(cloudflare.ZoneLoadBalancerUpdateParamsRulesOverridesSessionAffinityAttributesSamesiteAuto),
@@ -540,7 +538,6 @@ func TestZoneLoadBalancerUpdateWithOptionalParams(t *testing.T) {
"1": "9290f38c5d07c2e2f4df57b1f61d4196",
},
}),
- SessionAffinity: cloudflare.F(cloudflare.SessionAffinityCookie),
SessionAffinityAttributes: cloudflare.F(cloudflare.ZoneLoadBalancerUpdateParamsRulesOverridesSessionAffinityAttributes{
DrainDuration: cloudflare.F(100.000000),
Samesite: cloudflare.F(cloudflare.ZoneLoadBalancerUpdateParamsRulesOverridesSessionAffinityAttributesSamesiteAuto),
@@ -611,7 +608,6 @@ func TestZoneLoadBalancerUpdateWithOptionalParams(t *testing.T) {
"1": "9290f38c5d07c2e2f4df57b1f61d4196",
},
}),
- SessionAffinity: cloudflare.F(cloudflare.SessionAffinityCookie),
SessionAffinityAttributes: cloudflare.F(cloudflare.ZoneLoadBalancerUpdateParamsRulesOverridesSessionAffinityAttributes{
DrainDuration: cloudflare.F(100.000000),
Samesite: cloudflare.F(cloudflare.ZoneLoadBalancerUpdateParamsRulesOverridesSessionAffinityAttributesSamesiteAuto),
@@ -625,7 +621,6 @@ func TestZoneLoadBalancerUpdateWithOptionalParams(t *testing.T) {
Priority: cloudflare.F(int64(0)),
Terminates: cloudflare.F(true),
}}),
- SessionAffinity: cloudflare.F(cloudflare.SessionAffinityCookie),
SessionAffinityAttributes: cloudflare.F(cloudflare.ZoneLoadBalancerUpdateParamsSessionAffinityAttributes{
DrainDuration: cloudflare.F(100.000000),
Samesite: cloudflare.F(cloudflare.ZoneLoadBalancerUpdateParamsSessionAffinityAttributesSamesiteAuto),
@@ -647,6 +642,7 @@ func TestZoneLoadBalancerUpdateWithOptionalParams(t *testing.T) {
}
func TestZoneLoadBalancerList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -670,6 +666,7 @@ func TestZoneLoadBalancerList(t *testing.T) {
}
func TestZoneLoadBalancerDelete(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zoneratelimit_test.go b/zoneratelimit_test.go
index 01b60cecad7..f542c51bde1 100644
--- a/zoneratelimit_test.go
+++ b/zoneratelimit_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneRateLimitGet(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -41,6 +42,7 @@ func TestZoneRateLimitGet(t *testing.T) {
}
func TestZoneRateLimitListWithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesetting_test.go b/zonesetting_test.go
index 7deb584d969..d0919fc35d9 100644
--- a/zonesetting_test.go
+++ b/zonesetting_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingadvancedddo_test.go b/zonesettingadvancedddo_test.go
index 926247521a6..b6d7550d2a9 100644
--- a/zonesettingadvancedddo_test.go
+++ b/zonesettingadvancedddo_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingAdvancedDdoList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingalwaysonline_test.go b/zonesettingalwaysonline_test.go
index 06b42f59740..50560ef2023 100644
--- a/zonesettingalwaysonline_test.go
+++ b/zonesettingalwaysonline_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingAlwaysOnlineUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingAlwaysOnlineUpdate(t *testing.T) {
}
func TestZoneSettingAlwaysOnlineList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingalwaysusehttp_test.go b/zonesettingalwaysusehttp_test.go
index f8140569739..9c517cfd2ea 100644
--- a/zonesettingalwaysusehttp_test.go
+++ b/zonesettingalwaysusehttp_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingAlwaysUseHTTPUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingAlwaysUseHTTPUpdate(t *testing.T) {
}
func TestZoneSettingAlwaysUseHTTPList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingautomatichttpsrewrite_test.go b/zonesettingautomatichttpsrewrite_test.go
index 481d2080ded..c184170c686 100644
--- a/zonesettingautomatichttpsrewrite_test.go
+++ b/zonesettingautomatichttpsrewrite_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingAutomaticHTTPsRewriteUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingAutomaticHTTPsRewriteUpdate(t *testing.T) {
}
func TestZoneSettingAutomaticHTTPsRewriteList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingautomaticplatformoptimization_test.go b/zonesettingautomaticplatformoptimization_test.go
index a81b8a7da75..f25e94cae45 100644
--- a/zonesettingautomaticplatformoptimization_test.go
+++ b/zonesettingautomaticplatformoptimization_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingAutomaticPlatformOptimizationUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -50,6 +51,7 @@ func TestZoneSettingAutomaticPlatformOptimizationUpdate(t *testing.T) {
}
func TestZoneSettingAutomaticPlatformOptimizationList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingbrotli_test.go b/zonesettingbrotli_test.go
index a57816afa4e..ae7f6a76154 100644
--- a/zonesettingbrotli_test.go
+++ b/zonesettingbrotli_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingBrotliUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingBrotliUpdate(t *testing.T) {
}
func TestZoneSettingBrotliList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingbrowsercachettl_test.go b/zonesettingbrowsercachettl_test.go
index 4d667fc1f79..24febf44e60 100644
--- a/zonesettingbrowsercachettl_test.go
+++ b/zonesettingbrowsercachettl_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingBrowserCacheTtlUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingBrowserCacheTtlUpdate(t *testing.T) {
}
func TestZoneSettingBrowserCacheTtlList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingbrowsercheck_test.go b/zonesettingbrowsercheck_test.go
index 30a07581b35..cb68c772add 100644
--- a/zonesettingbrowsercheck_test.go
+++ b/zonesettingbrowsercheck_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingBrowserCheckUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingBrowserCheckUpdate(t *testing.T) {
}
func TestZoneSettingBrowserCheckList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingcachelevel_test.go b/zonesettingcachelevel_test.go
index b62d2547a78..4fa315c8eb9 100644
--- a/zonesettingcachelevel_test.go
+++ b/zonesettingcachelevel_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingCacheLevelUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingCacheLevelUpdate(t *testing.T) {
}
func TestZoneSettingCacheLevelList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingchallengettl_test.go b/zonesettingchallengettl_test.go
index 079b43e9151..a0f6de6b43c 100644
--- a/zonesettingchallengettl_test.go
+++ b/zonesettingchallengettl_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingChallengeTtlUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingChallengeTtlUpdate(t *testing.T) {
}
func TestZoneSettingChallengeTtlList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingcipher_test.go b/zonesettingcipher_test.go
index c5cd3a35487..84587bea9bc 100644
--- a/zonesettingcipher_test.go
+++ b/zonesettingcipher_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingCipherUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingCipherUpdate(t *testing.T) {
}
func TestZoneSettingCipherList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingdevelopmentmode_test.go b/zonesettingdevelopmentmode_test.go
index d8bf821ed08..68d35e907a5 100644
--- a/zonesettingdevelopmentmode_test.go
+++ b/zonesettingdevelopmentmode_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingDevelopmentModeUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingDevelopmentModeUpdate(t *testing.T) {
}
func TestZoneSettingDevelopmentModeList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingearlyhint_test.go b/zonesettingearlyhint_test.go
index 6f7221c5fff..6f76f27000c 100644
--- a/zonesettingearlyhint_test.go
+++ b/zonesettingearlyhint_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingEarlyHintUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingEarlyHintUpdate(t *testing.T) {
}
func TestZoneSettingEarlyHintList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingemailobfuscation_test.go b/zonesettingemailobfuscation_test.go
index c7fcdf3a0ca..4f30e3ddc68 100644
--- a/zonesettingemailobfuscation_test.go
+++ b/zonesettingemailobfuscation_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingEmailObfuscationUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingEmailObfuscationUpdate(t *testing.T) {
}
func TestZoneSettingEmailObfuscationList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingh2prioritization_test.go b/zonesettingh2prioritization_test.go
index 85eb939304d..035486192bc 100644
--- a/zonesettingh2prioritization_test.go
+++ b/zonesettingh2prioritization_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingH2PrioritizationUpdateWithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -46,6 +47,7 @@ func TestZoneSettingH2PrioritizationUpdateWithOptionalParams(t *testing.T) {
}
func TestZoneSettingH2PrioritizationList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettinghotlinkprotection_test.go b/zonesettinghotlinkprotection_test.go
index b1d1dcc1d56..ab6168a71f2 100644
--- a/zonesettinghotlinkprotection_test.go
+++ b/zonesettinghotlinkprotection_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingHotlinkProtectionUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingHotlinkProtectionUpdate(t *testing.T) {
}
func TestZoneSettingHotlinkProtectionList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettinghttp2_test.go b/zonesettinghttp2_test.go
index aee69f47a69..6721b34cc63 100644
--- a/zonesettinghttp2_test.go
+++ b/zonesettinghttp2_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingHttp2Update(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingHttp2Update(t *testing.T) {
}
func TestZoneSettingHttp2List(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettinghttp3_test.go b/zonesettinghttp3_test.go
index ae8b26b169f..e77d8fcaaab 100644
--- a/zonesettinghttp3_test.go
+++ b/zonesettinghttp3_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingHttp3Update(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingHttp3Update(t *testing.T) {
}
func TestZoneSettingHttp3List(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingimageresizing_test.go b/zonesettingimageresizing_test.go
index ee2e3954a0a..b52f41598ee 100644
--- a/zonesettingimageresizing_test.go
+++ b/zonesettingimageresizing_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingImageResizingUpdateWithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -46,6 +47,7 @@ func TestZoneSettingImageResizingUpdateWithOptionalParams(t *testing.T) {
}
func TestZoneSettingImageResizingList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingipgeolocation_test.go b/zonesettingipgeolocation_test.go
index 1d59338af63..763bd1dfadf 100644
--- a/zonesettingipgeolocation_test.go
+++ b/zonesettingipgeolocation_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingIPGeolocationUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingIPGeolocationUpdate(t *testing.T) {
}
func TestZoneSettingIPGeolocationList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingipv6_test.go b/zonesettingipv6_test.go
index b7fcd48fb47..034949a10b4 100644
--- a/zonesettingipv6_test.go
+++ b/zonesettingipv6_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingIpv6Update(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingIpv6Update(t *testing.T) {
}
func TestZoneSettingIpv6List(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingminify_test.go b/zonesettingminify_test.go
index c5cf46e0f3a..632bb2ee3f8 100644
--- a/zonesettingminify_test.go
+++ b/zonesettingminify_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingMinifyUpdateWithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -47,6 +48,7 @@ func TestZoneSettingMinifyUpdateWithOptionalParams(t *testing.T) {
}
func TestZoneSettingMinifyList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingmintlsversion_test.go b/zonesettingmintlsversion_test.go
index a7ac0cd655e..38bebf50aea 100644
--- a/zonesettingmintlsversion_test.go
+++ b/zonesettingmintlsversion_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingMinTlsVersionUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingMinTlsVersionUpdate(t *testing.T) {
}
func TestZoneSettingMinTlsVersionList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingmirage_test.go b/zonesettingmirage_test.go
index 5447e4f6ff8..67256d025e4 100644
--- a/zonesettingmirage_test.go
+++ b/zonesettingmirage_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingMirageUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingMirageUpdate(t *testing.T) {
}
func TestZoneSettingMirageList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingmobileredirect_test.go b/zonesettingmobileredirect_test.go
index 1f3197d0696..a3d17961083 100644
--- a/zonesettingmobileredirect_test.go
+++ b/zonesettingmobileredirect_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingMobileRedirectUpdateWithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -47,6 +48,7 @@ func TestZoneSettingMobileRedirectUpdateWithOptionalParams(t *testing.T) {
}
func TestZoneSettingMobileRedirectList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingnel_test.go b/zonesettingnel_test.go
index 5301459430e..83cc1768c16 100644
--- a/zonesettingnel_test.go
+++ b/zonesettingnel_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingNelUpdateWithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -48,6 +49,7 @@ func TestZoneSettingNelUpdateWithOptionalParams(t *testing.T) {
}
func TestZoneSettingNelList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingopportunisticencryption_test.go b/zonesettingopportunisticencryption_test.go
index c3c5c99ab55..4a333373884 100644
--- a/zonesettingopportunisticencryption_test.go
+++ b/zonesettingopportunisticencryption_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingOpportunisticEncryptionUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingOpportunisticEncryptionUpdate(t *testing.T) {
}
func TestZoneSettingOpportunisticEncryptionList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingopportunisticonion_test.go b/zonesettingopportunisticonion_test.go
index 6c7e7795744..506f854168e 100644
--- a/zonesettingopportunisticonion_test.go
+++ b/zonesettingopportunisticonion_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingOpportunisticOnionUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingOpportunisticOnionUpdate(t *testing.T) {
}
func TestZoneSettingOpportunisticOnionList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingorangetoorange_test.go b/zonesettingorangetoorange_test.go
index c5dd216bfab..b3d0cd13674 100644
--- a/zonesettingorangetoorange_test.go
+++ b/zonesettingorangetoorange_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingOrangeToOrangeUpdateWithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -46,6 +47,7 @@ func TestZoneSettingOrangeToOrangeUpdateWithOptionalParams(t *testing.T) {
}
func TestZoneSettingOrangeToOrangeList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingoriginerrorpagepassthrus_test.go b/zonesettingoriginerrorpagepassthrus_test.go
index 877fa38eaa5..d8391d32fe9 100644
--- a/zonesettingoriginerrorpagepassthrus_test.go
+++ b/zonesettingoriginerrorpagepassthrus_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingOriginErrorPagePassThrusUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingOriginErrorPagePassThrusUpdate(t *testing.T) {
}
func TestZoneSettingOriginErrorPagePassThrusList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingoriginmaxhttpversion_test.go b/zonesettingoriginmaxhttpversion_test.go
index 110bf1f6a64..04e79a55edd 100644
--- a/zonesettingoriginmaxhttpversion_test.go
+++ b/zonesettingoriginmaxhttpversion_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingOriginMaxHTTPVersionUpdateWithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -45,6 +46,7 @@ func TestZoneSettingOriginMaxHTTPVersionUpdateWithOptionalParams(t *testing.T) {
}
func TestZoneSettingOriginMaxHTTPVersionList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingpolish_test.go b/zonesettingpolish_test.go
index 8656c8d3fcf..5f08f35f402 100644
--- a/zonesettingpolish_test.go
+++ b/zonesettingpolish_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingPolishUpdateWithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -46,6 +47,7 @@ func TestZoneSettingPolishUpdateWithOptionalParams(t *testing.T) {
}
func TestZoneSettingPolishList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingprefetchpreload_test.go b/zonesettingprefetchpreload_test.go
index d50d884c4f1..369b10d17d2 100644
--- a/zonesettingprefetchpreload_test.go
+++ b/zonesettingprefetchpreload_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingPrefetchPreloadUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingPrefetchPreloadUpdate(t *testing.T) {
}
func TestZoneSettingPrefetchPreloadList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingprivacypass_test.go b/zonesettingprivacypass_test.go
index 6472facf74a..527f71cafa0 100644
--- a/zonesettingprivacypass_test.go
+++ b/zonesettingprivacypass_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingPrivacyPassUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingPrivacyPassUpdate(t *testing.T) {
}
func TestZoneSettingPrivacyPassList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingproxyreadtimeout_test.go b/zonesettingproxyreadtimeout_test.go
index dc2d24f50f4..12203256bc4 100644
--- a/zonesettingproxyreadtimeout_test.go
+++ b/zonesettingproxyreadtimeout_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingProxyReadTimeoutUpdateWithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -46,6 +47,7 @@ func TestZoneSettingProxyReadTimeoutUpdateWithOptionalParams(t *testing.T) {
}
func TestZoneSettingProxyReadTimeoutList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingpseudoipv4_test.go b/zonesettingpseudoipv4_test.go
index 99ea8af50b5..8170cf47d85 100644
--- a/zonesettingpseudoipv4_test.go
+++ b/zonesettingpseudoipv4_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingPseudoIpv4Update(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingPseudoIpv4Update(t *testing.T) {
}
func TestZoneSettingPseudoIpv4List(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingresponsebuffering_test.go b/zonesettingresponsebuffering_test.go
index c7c6901acf8..b715fc9fb66 100644
--- a/zonesettingresponsebuffering_test.go
+++ b/zonesettingresponsebuffering_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingResponseBufferingUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingResponseBufferingUpdate(t *testing.T) {
}
func TestZoneSettingResponseBufferingList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingrocketloader_test.go b/zonesettingrocketloader_test.go
index 18a586ba4fb..76abe9e3a16 100644
--- a/zonesettingrocketloader_test.go
+++ b/zonesettingrocketloader_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingRocketLoaderUpdateWithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -46,6 +47,7 @@ func TestZoneSettingRocketLoaderUpdateWithOptionalParams(t *testing.T) {
}
func TestZoneSettingRocketLoaderList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingsecurityheader_test.go b/zonesettingsecurityheader_test.go
index 3a646e7533d..37eda0a0dbc 100644
--- a/zonesettingsecurityheader_test.go
+++ b/zonesettingsecurityheader_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingSecurityHeaderUpdateWithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -50,6 +51,7 @@ func TestZoneSettingSecurityHeaderUpdateWithOptionalParams(t *testing.T) {
}
func TestZoneSettingSecurityHeaderList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingsecuritylevel_test.go b/zonesettingsecuritylevel_test.go
index cb2c602c07d..82c234e935c 100644
--- a/zonesettingsecuritylevel_test.go
+++ b/zonesettingsecuritylevel_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingSecurityLevelUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingSecurityLevelUpdate(t *testing.T) {
}
func TestZoneSettingSecurityLevelList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingserversideexclude_test.go b/zonesettingserversideexclude_test.go
index 002cf028c78..3f98cfc2267 100644
--- a/zonesettingserversideexclude_test.go
+++ b/zonesettingserversideexclude_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingServerSideExcludeUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingServerSideExcludeUpdate(t *testing.T) {
}
func TestZoneSettingServerSideExcludeList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingsortquerystringforcach_test.go b/zonesettingsortquerystringforcach_test.go
index 9fce8b89143..b934657ce42 100644
--- a/zonesettingsortquerystringforcach_test.go
+++ b/zonesettingsortquerystringforcach_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingSortQueryStringForCachUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingSortQueryStringForCachUpdate(t *testing.T) {
}
func TestZoneSettingSortQueryStringForCachList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingssl_test.go b/zonesettingssl_test.go
index 71fdf6c1ada..43e739c9da3 100644
--- a/zonesettingssl_test.go
+++ b/zonesettingssl_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingSslUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingSslUpdate(t *testing.T) {
}
func TestZoneSettingSslList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingsslrecommender_test.go b/zonesettingsslrecommender_test.go
index 2b2f711049d..0cbb0ab5432 100644
--- a/zonesettingsslrecommender_test.go
+++ b/zonesettingsslrecommender_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingSslRecommenderUpdateWithOptionalParams(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -46,6 +47,7 @@ func TestZoneSettingSslRecommenderUpdateWithOptionalParams(t *testing.T) {
}
func TestZoneSettingSslRecommenderList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingtls13_test.go b/zonesettingtls13_test.go
index 88d55cb0237..02ed2b3060f 100644
--- a/zonesettingtls13_test.go
+++ b/zonesettingtls13_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingTls1_3Update(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingTls1_3Update(t *testing.T) {
}
func TestZoneSettingTls1_3List(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingtlsclientauth_test.go b/zonesettingtlsclientauth_test.go
index e221059e799..62cd36a94b6 100644
--- a/zonesettingtlsclientauth_test.go
+++ b/zonesettingtlsclientauth_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingTlsClientAuthUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingTlsClientAuthUpdate(t *testing.T) {
}
func TestZoneSettingTlsClientAuthList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingtrueclientipheader_test.go b/zonesettingtrueclientipheader_test.go
index 2950e5acd49..8de86dafac7 100644
--- a/zonesettingtrueclientipheader_test.go
+++ b/zonesettingtrueclientipheader_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingTrueClientIPHeaderUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingTrueClientIPHeaderUpdate(t *testing.T) {
}
func TestZoneSettingTrueClientIPHeaderList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingwaf_test.go b/zonesettingwaf_test.go
index 4b0334df6de..b436713e9d7 100644
--- a/zonesettingwaf_test.go
+++ b/zonesettingwaf_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingWafUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingWafUpdate(t *testing.T) {
}
func TestZoneSettingWafList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingwebp_test.go b/zonesettingwebp_test.go
index 62c1e8a6c09..9fb0e561e78 100644
--- a/zonesettingwebp_test.go
+++ b/zonesettingwebp_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingWebpUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingWebpUpdate(t *testing.T) {
}
func TestZoneSettingWebpList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zonesettingwebsocket_test.go b/zonesettingwebsocket_test.go
index a6828a0af4e..e9d68493fd4 100644
--- a/zonesettingwebsocket_test.go
+++ b/zonesettingwebsocket_test.go
@@ -14,6 +14,7 @@ import (
)
func TestZoneSettingWebsocketUpdate(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
@@ -43,6 +44,7 @@ func TestZoneSettingWebsocketUpdate(t *testing.T) {
}
func TestZoneSettingWebsocketList(t *testing.T) {
+ t.Skip("skipped: tests are disabled for the time being")
baseURL := "http://localhost:4010"
if envURL, ok := os.LookupEnv("TEST_API_BASE_URL"); ok {
baseURL = envURL
diff --git a/zone.go b/zone.go
index 68d3af64ce8..16ab57713c6 100644
--- a/zone.go
+++ b/zone.go
@@ -74,44 +74,25 @@ func (r *ZoneService) List(ctx context.Context, query ZoneListParams, opts ...op
}
// Deletes an existing zone.
-func (r *ZoneService) Delete(ctx context.Context, identifier string, opts ...option.RequestOption) (res *ZoneAPIResponseSingleID, err error) {
+func (r *ZoneService) Delete(ctx context.Context, identifier string, opts ...option.RequestOption) (res *APIResponseSingleID, err error) {
opts = append(r.Options[:], opts...)
path := fmt.Sprintf("zones/%s", identifier)
err = requestconfig.ExecuteNewRequest(ctx, http.MethodDelete, path, nil, &res, opts...)
return
}
-// The session_affinity specifies the type of session affinity the load balancer
-// should use unless specified as "none" or ""(default). The supported types are
-// "cookie" and "ip_cookie". "cookie" - On the first request to a proxied load
-// balancer, a cookie is generated, encoding information of which origin the
-// request will be forwarded to. Subsequent requests, by the same client to the
-// same load balancer, will be sent to the origin server the cookie encodes, for
-// the duration of the cookie and as long as the origin server remains healthy. If
-// the cookie has expired or the origin server is unhealthy then a new origin
-// server is calculated and used. "ip_cookie" behaves the same as "cookie" except
-// the initial origin selection is stable and based on the client’s ip address.
-type SessionAffinity string
-
-const (
- SessionAffinityNone SessionAffinity = "none"
- SessionAffinityCookie SessionAffinity = "cookie"
- SessionAffinityIPCookie SessionAffinity = "ip_cookie"
- SessionAffinityEmpty SessionAffinity = "\"\""
-)
-
-type ZoneAPIResponseSingleID struct {
- Errors []ZoneAPIResponseSingleIDError `json:"errors"`
- Messages []ZoneAPIResponseSingleIDMessage `json:"messages"`
- Result ZoneAPIResponseSingleIDResult `json:"result,nullable"`
+type APIResponseSingleID struct {
+ Errors []APIResponseSingleIDError `json:"errors"`
+ Messages []APIResponseSingleIDMessage `json:"messages"`
+ Result APIResponseSingleIDResult `json:"result,nullable"`
// Whether the API call was successful
- Success bool `json:"success"`
- JSON zoneAPIResponseSingleIDJSON `json:"-"`
+ Success bool `json:"success"`
+ JSON apiResponseSingleIDJSON `json:"-"`
}
-// zoneAPIResponseSingleIDJSON contains the JSON metadata for the struct
-// [ZoneAPIResponseSingleID]
-type zoneAPIResponseSingleIDJSON struct {
+// apiResponseSingleIDJSON contains the JSON metadata for the struct
+// [APIResponseSingleID]
+type apiResponseSingleIDJSON struct {
Errors apijson.Field
Messages apijson.Field
Result apijson.Field
@@ -120,66 +101,85 @@ type zoneAPIResponseSingleIDJSON struct {
ExtraFields map[string]apijson.Field
}
-func (r *ZoneAPIResponseSingleID) UnmarshalJSON(data []byte) (err error) {
+func (r *APIResponseSingleID) UnmarshalJSON(data []byte) (err error) {
return apijson.UnmarshalRoot(data, r)
}
-type ZoneAPIResponseSingleIDError struct {
- Code int64 `json:"code,required"`
- Message string `json:"message,required"`
- JSON zoneAPIResponseSingleIDErrorJSON `json:"-"`
+type APIResponseSingleIDError struct {
+ Code int64 `json:"code,required"`
+ Message string `json:"message,required"`
+ JSON apiResponseSingleIDErrorJSON `json:"-"`
}
-// zoneAPIResponseSingleIDErrorJSON contains the JSON metadata for the struct
-// [ZoneAPIResponseSingleIDError]
-type zoneAPIResponseSingleIDErrorJSON struct {
+// apiResponseSingleIDErrorJSON contains the JSON metadata for the struct
+// [APIResponseSingleIDError]
+type apiResponseSingleIDErrorJSON struct {
Code apijson.Field
Message apijson.Field
raw string
ExtraFields map[string]apijson.Field
}
-func (r *ZoneAPIResponseSingleIDError) UnmarshalJSON(data []byte) (err error) {
+func (r *APIResponseSingleIDError) UnmarshalJSON(data []byte) (err error) {
return apijson.UnmarshalRoot(data, r)
}
-type ZoneAPIResponseSingleIDMessage struct {
- Code int64 `json:"code,required"`
- Message string `json:"message,required"`
- JSON zoneAPIResponseSingleIDMessageJSON `json:"-"`
+type APIResponseSingleIDMessage struct {
+ Code int64 `json:"code,required"`
+ Message string `json:"message,required"`
+ JSON apiResponseSingleIDMessageJSON `json:"-"`
}
-// zoneAPIResponseSingleIDMessageJSON contains the JSON metadata for the struct
-// [ZoneAPIResponseSingleIDMessage]
-type zoneAPIResponseSingleIDMessageJSON struct {
+// apiResponseSingleIDMessageJSON contains the JSON metadata for the struct
+// [APIResponseSingleIDMessage]
+type apiResponseSingleIDMessageJSON struct {
Code apijson.Field
Message apijson.Field
raw string
ExtraFields map[string]apijson.Field
}
-func (r *ZoneAPIResponseSingleIDMessage) UnmarshalJSON(data []byte) (err error) {
+func (r *APIResponseSingleIDMessage) UnmarshalJSON(data []byte) (err error) {
return apijson.UnmarshalRoot(data, r)
}
-type ZoneAPIResponseSingleIDResult struct {
+type APIResponseSingleIDResult struct {
// Identifier
- ID string `json:"id,required"`
- JSON zoneAPIResponseSingleIDResultJSON `json:"-"`
+ ID string `json:"id,required"`
+ JSON apiResponseSingleIDResultJSON `json:"-"`
}
-// zoneAPIResponseSingleIDResultJSON contains the JSON metadata for the struct
-// [ZoneAPIResponseSingleIDResult]
-type zoneAPIResponseSingleIDResultJSON struct {
+// apiResponseSingleIDResultJSON contains the JSON metadata for the struct
+// [APIResponseSingleIDResult]
+type apiResponseSingleIDResultJSON struct {
ID apijson.Field
raw string
ExtraFields map[string]apijson.Field
}
-func (r *ZoneAPIResponseSingleIDResult) UnmarshalJSON(data []byte) (err error) {
+func (r *APIResponseSingleIDResult) UnmarshalJSON(data []byte) (err error) {
return apijson.UnmarshalRoot(data, r)
}
+// The session_affinity specifies the type of session affinity the load balancer
+// should use unless specified as "none" or ""(default). The supported types are
+// "cookie" and "ip_cookie". "cookie" - On the first request to a proxied load
+// balancer, a cookie is generated, encoding information of which origin the
+// request will be forwarded to. Subsequent requests, by the same client to the
+// same load balancer, will be sent to the origin server the cookie encodes, for
+// the duration of the cookie and as long as the origin server remains healthy. If
+// the cookie has expired or the origin server is unhealthy then a new origin
+// server is calculated and used. "ip_cookie" behaves the same as "cookie" except
+// the initial origin selection is stable and based on the client’s ip address.
+type SessionAffinity string
+
+const (
+ SessionAffinityNone SessionAffinity = "none"
+ SessionAffinityCookie SessionAffinity = "cookie"
+ SessionAffinityIPCookie SessionAffinity = "ip_cookie"
+ SessionAffinityEmpty SessionAffinity = "\"\""
+)
+
type ZoneNewResponse struct {
Errors []ZoneNewResponseError `json:"errors"`
Messages []ZoneNewResponseMessage `json:"messages"`